<?php
/**
 * 파일명: functions.php
 * 파일위치: wp-content/themes/generatepress-child/functions.php
 * 역할: 자식테마 기능 정의
 * 수정일: 2025-03-21
 */

/**
 * 파일명: functions.php
 * 파일위치: wp-content/themes/generatepress-child/functions.php
 * 역할: 테마 색상 선택 기능 추가
 * 수정일: 2025-03-23
 */

// ===================================
// 테마 색상 선택 기능
// ===================================

/**
 * 테마 색상 선택 메뉴 추가
 * 
 * @param WP_Customize_Manager $wp_customize 워드프레스 Customizer 객체
 * @return void
 */
function theme_color_customizer_register($wp_customize) {
    // 새로운 섹션 추가
    $wp_customize->add_section('theme_color_section', array(
        'title'    => '테마 색상 설정',
        'priority' => 30,
    ));

    // 색상 선택 설정 추가
    $wp_customize->add_setting('theme_color_option', array(
        'default'           => 'blue',
        'sanitize_callback' => 'sanitize_theme_color',
        'transport'         => 'refresh',
    ));

    // 색상 선택 컨트롤 추가
	$wp_customize->add_control('theme_color_control', array(
		'label'    => '테마 색상 선택',
		'section'  => 'theme_color_section',
		'settings' => 'theme_color_option',
		'type'     => 'radio',
		'choices'  => array(
			'blue'  => '블루 (#18609C)',
			'gray'  => '그레이 (#4B5563)',
			'mint'  => '민트 (#ACC7B4)',
			'teal green' => '딥틸 (#02343F)',
			'green'  => '그린 (#07553B)',
			'wine'     => '와인 (#990011)',
			'purple'   => '퍼플 (#76528B)',
			'aqua'     => '아쿠아 (#ADEFD1)',
			'orange'   => '오렌지 (#F95700)',
			'sand'     => '샌드 (#D7C49E)',
			'pink'     => '핑크 (#DF6589)',
		),
	));
}
add_action('customize_register', 'theme_color_customizer_register');

/**
 * 테마 색상 값 유효성 검사
 * 
 * @param string $input 입력된 테마 색상 값
 * @return string 유효한 테마 색상 값
 */
function sanitize_theme_color($input) {
    $valid = array('blue', 'gray', 'mint', 'teal green', 'green', 'wine', 'purple', 'aqua', 'orange', 'sand', 'pink');
    if (in_array($input, $valid)) {
        return $input;
    }
    return 'blue';
}

/**
 * 선택된 테마 색상에 따라 CSS 변수 설정
 * 
 * @return string CSS 변수 정의 코드
 */
function theme_color_css() {
    $theme_color = get_theme_mod('theme_color_option', 'blue');
    
    // 선택된 색상에 따라 CSS 변수 설정
    $main_color = '#18609C'; // 기본값 (블루)
    $main_color_hover = '#1a70b7'; // 좀 더 어두운 톤으로 설정
    $secondary_color = 'rgba(24, 96, 156, 0.2)';
    $secondary_color_hover = 'rgba(24, 96, 156, 0.3)';
    $text_on_main = '#fff';
    
    if ($theme_color === 'gray') {
        $main_color = '#4B5563';
        $main_color_hover = '#374151';
        $secondary_color = 'rgba(75, 85, 99, 0.2)';
        $secondary_color_hover = 'rgba(75, 85, 99, 0.3)';
        $text_on_main = '#fff';
    } elseif ($theme_color === 'mint') {
        $main_color = '#ACC7B4';
        $main_color_hover = '#687E70';
        $secondary_color = 'rgba(172, 199, 180, 0.2)';
        $secondary_color_hover = 'rgba(172, 199, 180, 0.3)';
        $text_on_main = '#331B3F';
    } elseif ($theme_color === 'teal green') {
		$main_color = '#02343F';
		$main_color_hover = '#01232B'; // 더 어두운 버전
		$secondary_color = 'rgba(2, 52, 63, 0.2)';
		$secondary_color_hover = 'rgba(2, 52, 63, 0.3)';
		$text_on_main = '#fff'; // 어두운 배경에 흰색 텍스트
		$accent_color = '#F0EDCC'; // 크림색 액센트
	} elseif ($theme_color === 'green') {
		$main_color = '#07553B';
		$main_color_hover = '#053D2A'; // 더 어두운 버전
		$secondary_color = 'rgba(7, 85, 59, 0.2)';
		$secondary_color_hover = 'rgba(7, 85, 59, 0.3)';
		$text_on_main = '#fff'; // 어두운 배경에 흰색 텍스트
		$accent_color = '#CED46A'; // 연한 라임 그린 액센트
	} elseif ($theme_color === 'wine') {
		$main_color = '#990011';
		$main_color_hover = '#7A000E'; // 더 어두운 버전
		$secondary_color = 'rgba(153, 0, 17, 0.2)';
		$secondary_color_hover = 'rgba(153, 0, 17, 0.3)';
		$text_on_main = '#fff'; // 어두운 배경에 흰색 텍스트
		$accent_color = '#FCF6F5'; // 연한 크림색 액센트
	} elseif ($theme_color === 'purple') {
		$main_color = '#76528B';
		$main_color_hover = '#5F4170'; // 더 어두운 버전
		$secondary_color = 'rgba(118, 82, 139, 0.2)';
		$secondary_color_hover = 'rgba(118, 82, 139, 0.3)';
		$text_on_main = '#fff'; // 어두운 배경에 흰색 텍스트
		$accent_color = '#E9D8FE'; // 연한 라벤더 색상 액센트
	} elseif ($theme_color === 'aqua') {
		$main_color = '#ADEFD1';
		$main_color_hover = '#8FD9B5'; // 더 어두운 버전
		$secondary_color = 'rgba(173, 239, 209, 0.4)'; // 불투명도를 좀 더 높임
		$secondary_color_hover = 'rgba(173, 239, 209, 0.6)';
		$text_on_main = '#00203F'; // 밝은 배경에 어두운 텍스트
		$accent_color = '#00203F'; // 짙은 네이비 액센트
	} elseif ($theme_color === 'orange') {
		$main_color = '#F95700';
		$main_color_hover = '#D14800'; // 더 어두운 버전
		$secondary_color = 'rgba(249, 87, 0, 0.2)';
		$secondary_color_hover = 'rgba(249, 87, 0, 0.3)';
		$text_on_main = '#fff'; // 어두운 오렌지 배경에 흰색 텍스트
		$accent_color = '#003459'; // 짙은 네이비 블루 액센트
	} elseif ($theme_color === 'sand') {
		$main_color = '#D7C49E';
		$main_color_hover = '#C4B184'; // 더 어두운 버전
		$secondary_color = 'rgba(215, 196, 158, 0.2)';
		$secondary_color_hover = 'rgba(215, 196, 158, 0.3)';
		$text_on_main = '#343148'; // 베이지 배경에 어두운 텍스트
		$accent_color = '#343148'; // 짙은 남색 액센트
	} elseif ($theme_color === 'pink') {
		$main_color = '#DF6589';
		$main_color_hover = '#C84D71'; // 더 어두운 버전
		$secondary_color = 'rgba(223, 101, 137, 0.2)';
		$secondary_color_hover = 'rgba(223, 101, 137, 0.3)';
		$text_on_main = '#fff'; // 핑크 배경에 흰색 텍스트
		$accent_color = '#2E2E4F'; // 짙은 남색 액센트

	}
    
    // CSS 변수 설정
    $css = "
    :root {
        --theme-main-color: {$main_color};
        --theme-main-color-hover: {$main_color_hover};
        --theme-secondary-color: {$secondary_color};
        --theme-secondary-color-hover: {$secondary_color_hover};
        --theme-text-on-main: {$text_on_main};";
    
    // 그린 테마일 경우 액센트 색상 추가
    if ($theme_color === 'teal green') {
        $css .= "
        --theme-accent-color: {$accent_color};";
    }
    
    $css .= "
    }";
    
    return $css;
}

/**
 * 사용자 정의 CSS를 헤더에 직접 추가
 * 
 * @return void
 */
function theme_color_head_styles() {
    $custom_css = theme_color_css();
    echo '<style id="theme-color-vars">' . $custom_css . '</style>';
}
add_action('wp_head', 'theme_color_head_styles', 999);

// 기존 enqueue_styles 함수는 주석 처리 또는 제거
// function theme_color_enqueue_styles() {...}
// add_action('wp_enqueue_scripts', 'theme_color_enqueue_styles', 30);



// ===================================
// 1. 기본 설정
// ===================================

/* 서브섹션: 부모 테마 스타일 로드 */
add_action('wp_enqueue_scripts', 'generatepress_child_enqueue_styles');
function generatepress_child_enqueue_styles() {
    wp_enqueue_style('generatepress-style', get_template_directory_uri() . '/style.css');
    wp_enqueue_style('generatepress-child-style',
        get_stylesheet_directory_uri() . '/style.css',
        array('generatepress-style')
    );
}

// ===================================
// 2. 테마 지원 기능
// ===================================

/* 서브섹션: 테마 지원 기능 설정 */
add_action('after_setup_theme', 'custom_theme_setup');
function custom_theme_setup() {
    // 대표 이미지 지원
    add_theme_support('post-thumbnails');
    set_post_thumbnail_size(300, 200, true);
    
    // 로고 설정
    add_theme_support('custom-logo', array(
        'height'      => 60,
        'width'       => 200,
        'flex-height' => true,
        'flex-width'  => true,
    ));
}

// ===================================
// 3. 레이아웃 설정
// ===================================

/* 서브섹션: 사이드바 설정 */
add_filter('generate_sidebar_layout', 'custom_sidebar_layout');
function custom_sidebar_layout() {
   // 기본 레이아웃을 우측 사이드바로 설정
   return 'right-sidebar';
}

/* 서브섹션: 커스텀 최신 글 위젯 등록 */
function custom_recent_posts_widget() {
   register_widget('Custom_Recent_Posts_Widget');
}
add_action('widgets_init', 'custom_recent_posts_widget');

/* 서브섹션: 커스텀 최신 글 위젯 클래스 */
class Custom_Recent_Posts_Widget extends WP_Widget {
   function __construct() {
       parent::__construct(
           'custom_recent_posts',
           '커스텀 최신 글',
           array('description' => '썸네일이 있는 최신 글 목록을 표시합니다.')
       );
   }

   public function widget($args, $instance) {
       echo $args['before_widget'];
       
       $recent_posts = wp_get_recent_posts(array(
           'numberposts' => 5,
           'post_status' => 'publish'
       ));
       
       if($recent_posts) : ?>
           <div class="custom-recent-posts">
               <h3 class="widget-title">최신 글</h3>
               <ul>
               <?php foreach($recent_posts as $post) : 
                   $image_url = '';
                   if (has_post_thumbnail($post['ID'])) {
                       $image_url = get_the_post_thumbnail_url($post['ID'], array(90, 60));
                   } else {
                       // 본문에서 첫 번째 이미지 찾기
                       preg_match_all('/<img.+src=[\'"]([^\'"]+)[\'"].*>/i', $post['post_content'], $matches);
                       // 설정한 no-img-icon.png 이미지 사용
                       $image_url = !empty($matches[1][0]) ? $matches[1][0] : get_stylesheet_directory_uri() . '/images/no-img-icon.png';
                   }
               ?>
                   <li class="recent-post-item">
                       <a href="<?php echo get_permalink($post['ID']); ?>">
                           <div class="post-thumbnail">
                               <img src="<?php echo esc_url($image_url); ?>" alt="<?php echo esc_attr($post['post_title']); ?>">
                           </div>
                           <div class="post-content">
                               <h4><?php echo $post['post_title']; ?></h4>
                           </div>
                       </a>
                   </li>
               <?php endforeach; ?>
               </ul>
           </div>
       <?php endif;
       
       echo $args['after_widget'];
   }

   public function form($instance) {
       // 위젯 관리자 폼
   }

   public function update($new_instance, $old_instance) {
       return $new_instance;
   }
}

/* 서브섹션: 연관 포스트 위젯 등록 */
function related_posts_widget_register() {
    register_widget('Related_Posts_Widget');
}
add_action('widgets_init', 'related_posts_widget_register');

/**
 * 연관 포스트 위젯 클래스
 * 현재 글과 관련된 다른 글들을 사이드바에 표시합니다.
 * 
 * @param array $args 위젯 인자
 * @param array $instance 위젯 설정값
 * @return void
 */
class Related_Posts_Widget extends WP_Widget {
    function __construct() {
        parent::__construct(
            'related_posts_widget',
            '관련 글',
            array('description' => '현재 글과 관련된 다른 글들을 표시합니다.')
        );
    }

    public function widget($args, $instance) {
        echo $args['before_widget'];
        
        $title = !empty($instance['title']) ? $instance['title'] : '관련 글';
        $number = !empty($instance['number']) ? absint($instance['number']) : 5;
        
        echo $args['before_title'] . esc_html($title) . $args['after_title'];
        
        // 현재 글의 카테고리 또는 태그 가져오기
        global $post;
        if (!is_single()) {
            // 싱글 페이지가 아닌 경우 최신 글 표시
            $query_args = array(
                'posts_per_page' => $number,
                'post_type' => 'post',
                'post_status' => 'publish',
                'orderby' => 'date',
                'order' => 'DESC'
            );
        } else {
            // 현재 글의 카테고리 가져오기
            $categories = get_the_category($post->ID);
            $category_ids = array();
            foreach ($categories as $category) {
                $category_ids[] = $category->term_id;
            }
            
            // 같은 카테고리의 다른 글 가져오기
            $query_args = array(
                'posts_per_page' => $number,
                'post_type' => 'post',
                'post__not_in' => array($post->ID),
                'category__in' => !empty($category_ids) ? $category_ids : array(0), // 카테고리가 없을 경우 처리
                'orderby' => 'rand'
            );
        }
        
        $related_query = new WP_Query($query_args);
        
        if ($related_query->have_posts()) : ?>
            <ul class="related-posts-widget">
            <?php 
            $post_count = 0;
            while ($related_query->have_posts() && $post_count < $number) : 
                $related_query->the_post();
                $post_count++;
                
                $image_url = '';
                if (has_post_thumbnail()) {
                    $image_url = get_the_post_thumbnail_url(get_the_ID(), array(90, 60));
                } else {
                    // 본문에서 첫 번째 이미지 찾기
                    preg_match_all('/<img.+src=[\'"]([^\'"]+)[\'"].*>/i', get_the_content(), $matches);
                    // 설정한 no-img-icon.png 이미지 사용
                    $image_url = !empty($matches[1][0]) ? $matches[1][0] : get_stylesheet_directory_uri() . '/images/no-img-icon.png';
                }
            ?>
                <li class="recent-post-item">
                    <a href="<?php the_permalink(); ?>">
                        <div class="post-thumbnail">
                            <img src="<?php echo esc_url($image_url); ?>" alt="<?php echo esc_attr(get_the_title()); ?>">
                        </div>
                        <div class="post-content">
                            <h4><?php the_title(); ?></h4>
                        </div>
                    </a>
                </li>
            <?php endwhile; ?>
            </ul>
        <?php endif;
        
        wp_reset_postdata();
        
        echo $args['after_widget'];
    }

    public function form($instance) {
        $title = !empty($instance['title']) ? $instance['title'] : '관련 글';
        $number = !empty($instance['number']) ? absint($instance['number']) : 5;
        ?>
        <p>
            <label for="<?php echo esc_attr($this->get_field_id('title')); ?>">제목:</label>
            <input class="widefat" id="<?php echo esc_attr($this->get_field_id('title')); ?>" name="<?php echo esc_attr($this->get_field_name('title')); ?>" type="text" value="<?php echo esc_attr($title); ?>">
        </p>
        <p>
            <label for="<?php echo esc_attr($this->get_field_id('number')); ?>">표시할 글 수:</label>
            <input class="tiny-text" id="<?php echo esc_attr($this->get_field_id('number')); ?>" name="<?php echo esc_attr($this->get_field_name('number')); ?>" type="number" step="1" min="1" value="<?php echo esc_attr($number); ?>" size="3">
        </p>
        <?php
    }

    public function update($new_instance, $old_instance) {
        $instance = array();
        $instance['title'] = (!empty($new_instance['title'])) ? sanitize_text_field($new_instance['title']) : '관련 글';
        $instance['number'] = (!empty($new_instance['number'])) ? absint($new_instance['number']) : 5;
        return $instance;
    }
}

/* 서브섹션: 탭 형태의 최신글 및 인기글 위젯 V2 등록 */
function tabbed_posts_widget_v2_register() {
    register_widget('Tabbed_Posts_Widget_V2');
}
add_action('widgets_init', 'tabbed_posts_widget_v2_register');

/**
 * 탭 형태의 최신글 및 인기글 위젯 클래스 V2
 * 최신글과 인기글을 탭 형태로 표시합니다.
 * 개선된 버전 2.0(2025.03.21)
 * 
 * @param array $args 위젯 인자
 * @param array $instance 위젯 설정값
 * @return void
 */
class Tabbed_Posts_Widget_V2 extends WP_Widget {
    function __construct() {
        parent::__construct(
            'tabbed_posts_widget_v2',
            '탭 형태의 최신글 및 인기글 V2',
            array('description' => '최신글과 인기글을 탭 형태로 표시합니다. (개선된 버전)')
        );
        
        // 위젯 스크립트 로드
        add_action('wp_enqueue_scripts', array($this, 'enqueue_scripts'));
    }
    
    // 위젯 스크립트 등록
    public function enqueue_scripts() {
        // 위젯 관련 스크립트 등록
        wp_enqueue_script(
            'tabbed-posts-widget-v2-script',
            get_stylesheet_directory_uri() . '/js/tabbed-posts-widget-v2.js',
            array('jquery'),
            '2.0.0',
            true
        );
    }

    public function widget($args, $instance) {
        echo $args['before_widget'];
        
        $title = !empty($instance['title']) ? $instance['title'] : '';
        $latest_title = !empty($instance['latest_title']) ? $instance['latest_title'] : '최신글';
        $popular_title = !empty($instance['popular_title']) ? $instance['popular_title'] : '인기글';
        $number = !empty($instance['number']) ? absint($instance['number']) : 5;
        
        // 고유 ID 생성 (여러 위젯 인스턴스 지원)
        $tabs_id = 'tabs-v2-' . $this->id;
        
        // 위젯 타이틀 출력
        if (!empty($title)) {
            echo $args['before_title'] . apply_filters('widget_title', $title) . $args['after_title'];
        }
        
        // 탭 버튼 출력
        ?>
        <div class="tabbed-posts-widget-v2" id="widget-v2-<?php echo esc_attr($this->id); ?>">
            <div class="tabs-nav">
                <button class="tab-button active" data-tab="latest" data-tabs-id="<?php echo esc_attr($tabs_id); ?>"><?php echo esc_html($latest_title); ?></button>
                <button class="tab-button" data-tab="popular" data-tabs-id="<?php echo esc_attr($tabs_id); ?>"><?php echo esc_html($popular_title); ?></button>
            </div>
            
            <div class="tabs-content">
                <!-- 최신글 탭 -->
                <div id="<?php echo esc_attr($tabs_id); ?>-latest" class="tab-content active">
                    <?php
                    // 최신글 가져오기
                    $latest_posts = get_posts(array(
                        'posts_per_page' => $number,
                        'post_status' => 'publish',
                        'orderby' => 'date',
                        'order' => 'DESC'
                    ));
                    
                    if($latest_posts) : ?>
                        <ul class="posts-list">
                        <?php foreach($latest_posts as $post) : 
                            setup_postdata($post);
                            $image_url = '';
                            if (has_post_thumbnail($post->ID)) {
                                $image_url = get_the_post_thumbnail_url($post->ID, array(90, 60));
                            } else {
                                // 본문에서 첫 번째 이미지 찾기
                                preg_match_all('/<img.+src=[\'"]([^\'"]+)[\'"].*>/i', $post->post_content, $matches);
                                // 설정한 no-img-icon.png 이미지 사용
                                $image_url = !empty($matches[1][0]) ? $matches[1][0] : get_stylesheet_directory_uri() . '/images/no-img-icon.png';
                            }
                        ?>
                            <li class="recent-post-item">
                                <a href="<?php echo get_permalink($post->ID); ?>">
                                    <div class="post-thumbnail">
                                        <img src="<?php echo esc_url($image_url); ?>" alt="<?php echo esc_attr(get_the_title($post->ID)); ?>">
                                    </div>
                                    <div class="post-content">
                                        <h4><?php echo get_the_title($post->ID); ?></h4>
                                    </div>
                                </a>
                            </li>
                        <?php endforeach; wp_reset_postdata(); ?>
                        </ul>
                    <?php else: ?>
                        <p class="no-posts">최신글이 없습니다.</p>
                    <?php endif; ?>
                </div>
                
                <!-- 인기글 탭 -->
                <div id="<?php echo esc_attr($tabs_id); ?>-popular" class="tab-content">
                    <?php
                    // 인기글(조회수 기준) 가져오기
                    $popular_args = array(
                        'posts_per_page' => $number, // 위젯 설정에서 지정한 개수로 설정
                        'post_type' => 'post',
                        'post_status' => 'publish',
                        'meta_key' => 'post_views_count', // 조회수 메타필드
                        'orderby' => 'meta_value_num',
                        'order' => 'DESC'
                    );
                    
                    $popular_query = new WP_Query($popular_args);
                    
                    if($popular_query->have_posts()) : ?>
                        <ul class="posts-list">
                        <?php 
                        $count = 0; // 포스트 카운터 추가
                        while($popular_query->have_posts() && $count < $number) : // 지정된 개수만큼만 표시
                            $popular_query->the_post();
                            $count++;
                            
                            $image_url = '';
                            if (has_post_thumbnail()) {
                                $image_url = get_the_post_thumbnail_url(get_the_ID(), array(90, 60));
                            } else {
                                // 본문에서 첫 번째 이미지 찾기
                                preg_match_all('/<img.+src=[\'"]([^\'"]+)[\'"].*>/i', get_the_content(), $matches);
                                // 설정한 no-img-icon.png 이미지 사용
                                $image_url = !empty($matches[1][0]) ? $matches[1][0] : get_stylesheet_directory_uri() . '/images/no-img-icon.png';
                            }
                        ?>
                            <li class="recent-post-item">
                                <a href="<?php the_permalink(); ?>">
                                    <div class="post-thumbnail">
                                        <img src="<?php echo esc_url($image_url); ?>" alt="<?php echo esc_attr(get_the_title()); ?>">
                                    </div>
                                    <div class="post-content">
                                        <h4><?php the_title(); ?></h4>
                                    </div>
                                </a>
                            </li>
                        <?php endwhile; ?>
                        </ul>
                    <?php else: ?>
                        <p class="no-posts">아직 인기글이 없습니다.</p>
                    <?php endif;
                    
                    wp_reset_postdata();
                    ?>
                </div>
            </div>
        </div>
        
        <script>
        (function($) {
            $(document).ready(function() {
                // 탭 클릭 이벤트 처리
                $('#widget-v2-<?php echo esc_js($this->id); ?> .tab-button').on('click', function() {
                    const tabsId = $(this).data('tabs-id');
                    const tabName = $(this).data('tab');
                    
                    // 모든 버튼에서 active 클래스 제거
                    $('#widget-v2-<?php echo esc_js($this->id); ?> .tab-button').removeClass('active');
                    
                    // 모든 탭 컨텐츠 숨기기
                    $('#' + tabsId + '-latest, #' + tabsId + '-popular').removeClass('active');
                    
                    // 클릭한 버튼 활성화
                    $(this).addClass('active');
                    
                    // 해당 탭 컨텐츠 표시
                    $('#' + tabsId + '-' + tabName).addClass('active');
                });
            });
        })(jQuery);
        </script>
        <?php
        
        echo $args['after_widget'];
    }

    public function form($instance) {
        $title = !empty($instance['title']) ? $instance['title'] : '';
        $latest_title = !empty($instance['latest_title']) ? $instance['latest_title'] : '최신글';
        $popular_title = !empty($instance['popular_title']) ? $instance['popular_title'] : '인기글';
        $number = !empty($instance['number']) ? absint($instance['number']) : 5;
        ?>
        <p>
            <label for="<?php echo esc_attr($this->get_field_id('title')); ?>">위젯 제목:</label>
            <input class="widefat" id="<?php echo esc_attr($this->get_field_id('title')); ?>" name="<?php echo esc_attr($this->get_field_name('title')); ?>" type="text" value="<?php echo esc_attr($title); ?>">
        </p>
        <p>
            <label for="<?php echo esc_attr($this->get_field_id('latest_title')); ?>">최신글 탭 제목:</label>
            <input class="widefat" id="<?php echo esc_attr($this->get_field_id('latest_title')); ?>" name="<?php echo esc_attr($this->get_field_name('latest_title')); ?>" type="text" value="<?php echo esc_attr($latest_title); ?>">
        </p>
        <p>
            <label for="<?php echo esc_attr($this->get_field_id('popular_title')); ?>">인기글 탭 제목:</label>
            <input class="widefat" id="<?php echo esc_attr($this->get_field_id('popular_title')); ?>" name="<?php echo esc_attr($this->get_field_name('popular_title')); ?>" type="text" value="<?php echo esc_attr($popular_title); ?>">
        </p>
        <p>
            <label for="<?php echo esc_attr($this->get_field_id('number')); ?>">표시할 글 수:</label>
            <input class="tiny-text" id="<?php echo esc_attr($this->get_field_id('number')); ?>" name="<?php echo esc_attr($this->get_field_name('number')); ?>" type="number" step="1" min="1" value="<?php echo esc_attr($number); ?>" size="3">
        </p>
        <?php
    }

    public function update($new_instance, $old_instance) {
        $instance = array();
        $instance['title'] = (!empty($new_instance['title'])) ? sanitize_text_field($new_instance['title']) : '';
        $instance['latest_title'] = (!empty($new_instance['latest_title'])) ? sanitize_text_field($new_instance['latest_title']) : '최신글';
        $instance['popular_title'] = (!empty($new_instance['popular_title'])) ? sanitize_text_field($new_instance['popular_title']) : '인기글';
        $instance['number'] = (!empty($new_instance['number'])) ? absint($new_instance['number']) : 5;
        return $instance;
    }
}


// ===================================
// 4. 부트스트랩 추가
// ===================================

/* 서브섹션: 부트스트랩 리소스 로드 */
/* add_action('wp_enqueue_scripts', 'add_bootstrap_resources');
function add_bootstrap_resources() {
    wp_enqueue_style('bootstrap', 'https://cdn.jsdelivr.net/npm/bootstrap@5.3.0/dist/css/bootstrap.min.css');
    wp_enqueue_script('bootstrap-bundle', 'https://cdn.jsdelivr.net/npm/bootstrap@5.3.0/dist/js/bootstrap.bundle.min.js', array(), null, true);
    wp_enqueue_style('bootstrap-icons', 'https://cdn.jsdelivr.net/npm/bootstrap-icons@1.11.0/font/bootstrap-icons.css');
} */

// ===================================
// 5. 포스트 표시 설정
// ===================================

/* 서브섹션: 기존 출력 요소 제거 */
add_action('wp', 'manage_content_display');
function manage_content_display() {
    if (!is_single()) {
        // 블로그 목록 페이지에서만 기본 요소 제거
        remove_action('generate_after_entry_header', 'generate_post_image');
        remove_action('generate_after_entry_header', 'generate_post_content');
        remove_action('generate_after_entry_content', 'generate_footer_meta');
        
        // 카테고리 페이지에서 중복 발췌문 제거
        if (is_category() || is_archive()) {
            add_filter('get_the_excerpt', 'remove_duplicate_excerpt_in_category', 999);
            add_filter('the_excerpt', 'remove_duplicate_excerpt_in_category', 999);
        }
    } else {
        // 싱글 포스트 페이지에서는 커스텀 레이아웃 제거
        remove_action('generate_after_entry_header', 'custom_post_layout', 5);
    }
}


// ===================================
// 6. 관리자 에디터 설정
// ===================================

/* 서브섹션: 에디터 스타일 지원 */
function custom_editor_settings() {
    // 에디터 스타일 지원
    add_theme_support('editor-styles');
    
    // 기본 스타일시트 추가
    add_editor_style('style.css');
    
    // 와이드 얼라인먼트 지원
    add_theme_support('align-wide');
    
    // 최대 너비 설정
    if (!isset($GLOBALS['content_width'])) {
        $GLOBALS['content_width'] = 1320;
    }
}
add_action('after_setup_theme', 'custom_editor_settings');

/* 서브섹션: 블록 에디터 최대 너비 필터 */
function custom_content_width() {
    return 1320;
}
add_filter('gutenberg_max_width', 'custom_content_width');



// ===================================
// 7. 관련 글 설정
// ===================================

/* 서브섹션: 관련 글 표시 함수 */
function add_related_posts() {
    if (!is_single()) return; // 싱글 포스트 페이지가 아니면 실행하지 않음
    
    ?>
    <div class="related-posts">
        <h4>
            <?php 
            $categories = get_the_category();
            if (!empty($categories)) {
                echo esc_html($categories[0]->name); 
            }
            ?> 
            카테고리의 다른 글
        </h4>

        <?php 
        $current_post_type = get_post_type();
        $query_args = array( 
            'category__in' => wp_get_post_categories(get_the_ID()),
            'post_type'      => $current_post_type,
            'post__not_in' => array(get_the_ID()),
            'posts_per_page'  => '5',
            'orderby' => 'rand'
        );

        $related_cats_post = new WP_Query($query_args);

        if($related_cats_post->have_posts()): 
        ?>
            <ul>
                <?php while($related_cats_post->have_posts()): $related_cats_post->the_post(); ?>
                    <li>
                        <a href="<?php the_permalink(); ?>">
                            <?php the_title(); ?>
                        </a>
                    </li>
                <?php endwhile; ?>
            </ul>

            <?php 
            // Restore original Post Data
            wp_reset_postdata();
        endif; 
        ?>
    </div><br>
    <?php
}

/* 서브섹션: 관련 글을 콘텐츠 끝에 추가 */
add_action('generate_after_entry_content', 'add_related_posts', 20);


// ===================================
// 8. 푸터 카피라이트 수정
// ===================================

/* 서브섹션: 푸터 카피라이트 필터 */
add_filter('generate_copyright', 'custom_copyright');
function custom_copyright() {
   return 'Copyright © ' . date('Y') . ' ' . get_bloginfo('name') . '. All rights reserved. ' . 
          'Developed by <a href="https://url.kr/p/wp-plugin/" target="_blank" rel="noopener noreferrer">URL.KR</a>';
}


// ===================================
// 9. 플로팅 버튼 추가
// ===================================

/* 서브섹션: 플로팅 버튼 추가 */
function add_floating_buttons() {
    // 싱글 포스트 페이지인지 확인
    if (is_single()) {
        // 싱글 포스트 페이지용 플로팅 버튼 (부트스트랩 아이콘 사용)
        ?>
        <div class="floating-buttons">
            <button class="floating-button scroll-top-button" onclick="scrollToTop()" aria-label="맨 위로 이동">
                <i class="bi bi-arrow-up"></i>
            </button>
            <button class="floating-button share-button" onclick="shareApp()" aria-label="공유하기">
                <i class="bi bi-share"></i>
            </button>
        </div>
        <?php
    } else {
        // 메인 페이지용 플로팅 버튼 (유니코드 화살표 사용)
        ?>
        <div class="floating-buttons">
            <button class="floating-button scroll-top-button" onclick="scrollToTop()" aria-label="맨 위로 이동">
                <span style="font-size: 20px; line-height: 1; display: block;">↑</span>
            </button>
            <button class="floating-button share-button" onclick="shareApp()" aria-label="공유하기">
			  <span style="font-size: 20px; line-height: 1; display: block;">♆</span>
			</button>
        </div>
        <?php
    }
    ?>

    <script>
    // 스크롤 탑 기능
    function scrollToTop() {
        window.scrollTo({
            top: 0,
            behavior: 'smooth'
        });
    }

    // 공유 기능
    function shareApp() {
        if (navigator.share) {
            navigator.share({
                title: '<?php echo get_bloginfo('name'); ?>',
                text: '<?php echo get_bloginfo('description'); ?>',
                url: window.location.href
            }).catch(() => fallbackShare());
        } else {
            fallbackShare();
        }
    }

    // 공유 폴백 기능
    function fallbackShare() {
        navigator.clipboard.writeText(window.location.href)
            .then(() => alert('URL이 복사되었습니다!'))
            .catch(() => alert('URL 복사에 실패했습니다.'));
    }

    // 스크롤 이벤트 최적화
    const floatingButtons = document.querySelector('.floating-buttons');
    let lastScrollY = window.scrollY;
    let ticking = false;

    window.addEventListener('scroll', () => {
        if (!ticking) {
            window.requestAnimationFrame(() => {
                floatingButtons.style.display = window.scrollY > 200 ? 'flex' : 'none';
                ticking = false;
            });
            ticking = true;
        }
    });
    </script>
    <?php
}
add_action('wp_footer', 'add_floating_buttons');


// ===================================
// 10. 브레드크럼 기능 추가
// ===================================

/* 서브섹션: 사용자 정의 브레드크럼 함수 */
function custom_breadcrumb() {
    // 홈페이지에서는 표시하지 않음
    if (is_front_page()) return;
    
    echo '<div class="breadcrumb">';
    echo '<span class="breadcrumb-item"><a href="' . home_url() . '"><i class="bi bi-house-door"></i> Home</a></span>';
    
    if (is_singular('post')) {
        // 단일 포스트인 경우
        $categories = get_the_category();
        if ($categories) {
            echo '<span class="breadcrumb-separator">›</span>';
            echo '<span class="breadcrumb-item"><a href="' . esc_url(get_category_link($categories[0]->term_id)) . '">' 
                 . esc_html($categories[0]->name) . '</a></span>';
        }
        echo '<span class="breadcrumb-separator">›</span>';
        echo '<span class="breadcrumb-item current">' . get_the_title() . '</span>';
    } elseif (is_category()) {
        // 카테고리 페이지인 경우
        echo '<span class="breadcrumb-separator">›</span>';
        echo '<span class="breadcrumb-item current">' . single_cat_title('', false) . '</span>';
    } elseif (is_page()) {
        // 페이지인 경우
        echo '<span class="breadcrumb-separator">›</span>';
        echo '<span class="breadcrumb-item current">' . get_the_title() . '</span>';
    } elseif (is_search()) {
        // 검색 결과 페이지인 경우
        echo '<span class="breadcrumb-separator">›</span>';
        echo '<span class="breadcrumb-item current">검색결과: ' . get_search_query() . '</span>';
    }
    
    echo '</div>';
}

/* 서브섹션: 브레드크럼 출력 위치 설정 */
add_action('generate_before_main_content', 'custom_breadcrumb', 5);


// ===================================
// 11. 조회수 기능
// ===================================

/* 서브섹션: 조회수 기록 기능 추가 */
function set_post_views() {
    if (is_single()) {
        $post_id = get_the_ID();
        $count_key = 'post_views_count';
        $count = get_post_meta($post_id, $count_key, true);
        
        if ($count == '') {
            delete_post_meta($post_id, $count_key);
            add_post_meta($post_id, $count_key, '1');
        } else {
            $count++;
            update_post_meta($post_id, $count_key, $count);
        }
    }
}
add_action('wp_head', 'set_post_views');

/* 서브섹션: 조회수 표시 함수 */
function get_post_views($post_id) {
    $count_key = 'post_views_count';
    $count = get_post_meta($post_id, $count_key, true);
    
    if ($count == '') {
        delete_post_meta($post_id, $count_key);
        add_post_meta($post_id, $count_key, '0');
        return "0";
    }
    
    return $count;
}


// ===================================
// 12. 검색 폼 커스터마이징
// ===================================

/* 서브섹션: 검색 폼 커스터마이징 */
function custom_search_form($form) {
    // 싱글 포스트 페이지인지 확인
    if (is_single()) {
        // 싱글 포스트 페이지용 검색 폼 (부트스트랩 아이콘 사용)
        $form = '<form role="search" method="get" class="search-form" action="' . esc_url(home_url('/')) . '">
            <label>
                <span class="screen-reader-text">' . _x('검색어:', 'label') . '</span>
                <span class="search-icon-wrapper">
                    <i class="bi bi-search"></i>
                </span>
                <input type="search" class="search-field" placeholder="' . esc_attr_x('검색어를 입력하세요...', 'placeholder') . '" value="' . get_search_query() . '" name="s" />
            </label>
            <input type="submit" class="search-submit" value="' . esc_attr_x('검색', 'submit button') . '" />
        </form>';
    } else {
        // 메인 페이지용 검색 폼 (아이콘 제거)
        $form = '<form role="search" method="get" class="search-form" action="' . esc_url(home_url('/')) . '">
            <label>
                <span class="screen-reader-text">' . _x('검색어:', 'label') . '</span>
                <input type="search" class="search-field" placeholder="' . esc_attr_x('검색어를 입력하세요...', 'placeholder') . '" value="' . get_search_query() . '" name="s" />
            </label>
            <input type="submit" class="search-submit" value="' . esc_attr_x('검색', 'submit button') . '" />
        </form>';
    }

    return $form;
}
add_filter('get_search_form', 'custom_search_form');


// ===================================
// 13. 검색 위젯 제목 커스터마이징
// ===================================

/* 서브섹션: 검색 위젯 제목에 클래스 추가 */
function customize_search_widget_title() {
    ?>
    <script>
    document.addEventListener('DOMContentLoaded', function() {
        // 검색 위젯 타이틀에 클래스 추가
        const searchWidgetTitles = document.querySelectorAll('.widget_search .widget-title');
        searchWidgetTitles.forEach(function(title) {
            // 이미 처리되지 않은 경우에만 처리
            if (!title.classList.contains('customized')) {
                title.classList.add('customized');
            }
        });
    });
    </script>
    <?php
}
add_action('wp_footer', 'customize_search_widget_title');


// ===================================
// 14. 블록 기반 검색 위젯 스타일 초기화
// ===================================

/* 서브섹션: 블록 기반 검색 위젯 스타일 초기화 */
function enqueue_custom_block_search_styles() {
    ?>
    <script>
    document.addEventListener('DOMContentLoaded', function() {
        // 검색 위젯 컨테이너 찾기
        const searchBlocks = document.querySelectorAll('.widget_block.widget_search');
        
        searchBlocks.forEach(function(block) {
            // 검색 폼 찾기
            const searchForm = block.querySelector('.wp-block-search__inside-wrapper');
            if (!searchForm) return;
            
            // 검색 입력 필드
            const searchInput = block.querySelector('.wp-block-search__input');
            if (!searchInput) return;
            
            // 검색 버튼
            const searchButton = block.querySelector('.wp-block-search__button');
            
            // 싱글 포스트 페이지인지 확인
            if (document.body.classList.contains('single')) {
                // 부트스트랩 아이콘 관련 코드 유지
            } else {
                // 메인 페이지에서는 아이콘 관련 코드 제거
                // 기존에 추가된 아이콘 요소가 있다면 제거
                const existingIcon = searchForm.querySelector('.search-icon-wrapper');
                if (existingIcon) {
                    existingIcon.remove();
                }
                
                // 패딩 초기화
                searchInput.style.paddingLeft = '';
            }
            
            // 플레이스홀더 추가
            searchInput.setAttribute('placeholder', '검색어를 입력하세요...');
            
            // 버튼 텍스트 설정
            if (searchButton && searchButton.textContent.trim() === '') {
                searchButton.textContent = '검색';
            }
        });
    });
    </script>
    <?php
}
add_action('wp_footer', 'enqueue_custom_block_search_styles');


// ===================================
// 15. 카테고리 페이지에서 중복 발췌문 제거
// ===================================

/* 서브섹션: 중복 발췌문 제거 */
function remove_duplicate_excerpt_in_category($excerpt) {
    if (is_category() || is_archive()) {
        return '';
    }
    return $excerpt;
}

/* 서브섹션: 새로운 레이아웃 추가 */
add_action('generate_after_entry_header', 'custom_post_layout', 5);
function custom_post_layout() {
    // 싱글 포스트 페이지에서는 실행하지 않음
    if (is_single()) {
        return;
    }
    
    global $post;
    
    // 이미지 처리
    $image_html = '';
    if (has_post_thumbnail()) {
        $image_html = get_the_post_thumbnail(null, 'medium', array('class' => 'custom-thumb'));
    } else {
        preg_match_all('/<img.+src=[\'"]([^\'"]+)[\'"].*>/i', $post->post_content, $matches);
        if (!empty($matches[1][0])) {
            $image_html = sprintf(
                '<img src="%s" class="custom-thumb" alt="%s">',
                esc_url($matches[1][0]),
                esc_attr(get_the_title())
            );
        }
    }
    
    // 발췌문 처리
    $excerpt = has_excerpt() ? get_the_excerpt() : wp_trim_words(get_the_content(), 50);
    ?>
    <div class="custom-post-wrap">
        <div class="custom-post-content">
            <div class="custom-excerpt">
                <?php echo $excerpt; ?>
            </div>
            <div class="custom-post-meta">
                <a href="<?php the_permalink(); ?>" class="btn btn-primary">더보기</a>
            </div>
        </div>
        <?php if ($image_html) : ?>
            <div class="custom-post-thumb">
                <a href="<?php the_permalink(); ?>">
                    <?php echo $image_html; ?>
                </a>
            </div>
        <?php endif; ?>
    </div>
    <?php
}